﻿local ADDONNAME, TrappersSenseData = ...
local VERSION = GetAddOnMetadata(ADDONNAME,"Version")
TrappersSenseData.Functions = {}
local TrappersSense = TrappersSenseData.Functions;

local _;--For good measure
-- Slash Commands
SLASH_TrappersSense1 = "/trapsense";	-- /Commands

--[SVARS]Saved Variables, Per Character
local defaults  = {}
-- Text Color Constants
local CWhite  		= "|cffffffff";
local CRed    		= "|cffff0000";
local CGreen  		= "|cff00ff00";
local CBlue   		= "|cff6060ff";
local CCyan   		= "|cff00ffff";
local CMagenta		= "|cffff00ff";
local CYellow 		= "|cffffff00";
local CErrorRed		= "|cffff4040";
local CValidGreen	= "|cff40c840";
local RarityInfo = {
		[1] 		= {Desc = "Poor", 		Color = "|cff879d8a"},
		[2]			= {Desc = "Common", 	Color = "|cffffffff"},
		[3] 		= {Desc = "Uncommon", 	Color = "|cff00ff00"},
		[4] 		= {Desc = "Rare", 		Color = "|cff206edc"},
		[5] 		= {Desc = "Epic", 		Color = "|cffc030c0"},	--Likely Never Used
		[6] 		= {Desc = "Legendary",	Color = "|cffff8000"}	--Never Used: Just in case
}
--Frame Variables
local FrameUI 		= {};
--List Variables
local PetList 		= {}
local PetListSize 	= 0;
local waitTimer 	= 0

function TrappersSense_OnLoad(self)
	self:SetBackdropBorderColor(TOOLTIP_DEFAULT_COLOR.r, TOOLTIP_DEFAULT_COLOR.g, TOOLTIP_DEFAULT_COLOR.b);
	self:SetBackdropColor(TOOLTIP_DEFAULT_BACKGROUND_COLOR.r, TOOLTIP_DEFAULT_BACKGROUND_COLOR.g, TOOLTIP_DEFAULT_BACKGROUND_COLOR.b);
	self:RegisterEvent("ADDON_LOADED");
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE");
	self:RegisterEvent("PET_JOURNAL_PET_DELETED");
	self:RegisterEvent("CHAT_MSG_SYSTEM");
end

function TrappersSense_OnEvent(self, event, ...)
	local addon = ...
	if (event == "ADDON_LOADED") then
		if ((...) == ADDONNAME) then
			TrappersSense.Initialize(self)
			TrappersSense.LoadPets()
			DEFAULT_CHAT_FRAME:AddMessage(CGreen..ADDONNAME.." "..CRed..VERSION..CGreen..": Loaded. ")--Type "..Cyan..SLASH_TrappersSense1..Green.." for help.");
		end
	elseif (event == "PET_JOURNAL_LIST_UPDATE" or 
			event == "PET_JOURNAL_PET_DELETED") then
		if(waitTimer + 1 < time()) then --limit to once every second
			waitTimer = time();
		else 
			return;
		end
		TrappersSense.LoadPets();
	end
end

function TrappersSense.Initialize(self)
	local Button = CreateFrame("Button", nil, PetJournal, "ButtonTemplate")
	Button:SetSize(15,15)
	Button:SetPoint("BOTTOMLEFT",PetJournal,"BOTTOMLEFT",250,6)
end

function SlashCmdList.TrappersSense(msg)

end

function TrappersSense.LoadPets()
	C_PetJournal.ClearSearchFilter();
	C_PetJournal.AddAllPetTypesFilter()
	C_PetJournal.AddAllPetSourcesFilter()
	PetList = {}
	for i = 1, 500 do
		local PID, sID, owned, Nick, Lv, fav, _, spec, tex, cat = C_PetJournal.GetPetInfoByIndex(i)
		if (not owned) then break end;
		table.insert(PetList, {PetID = PID, SpeciesID = sID, IsOwned = owned, NickName = Nick, Level = Lv, IsFavorite = fav, SpeciesName = spec, IconTexture = tex, PetType = cat})
		PetListSize = i;
	end
end

function TrappersSense.AcquirePet(msg)
	if(msg == nil) or (string.find(msg, ("added to your pet journal")) == nil) then return end;
	TrappersSense.LoadPets()
end

function TrappersSense.Hook(self)
	--if Tooltip for non BattlePet, ignore
	local species, unit = self:GetUnit()
	if(not UnitIsWildBattlePet(unit)) then return end;
	--variables
	Owned = {[1] = 0, [2] = 0, [3] = 0}
	local counter = 0;
	local name;
	--Scan tooltip
	local ToolTipText = {}
	for i = 1, select("#", self:GetRegions()) do
        local region = select(i, self:GetRegions())
        if (region and region:GetObjectType() == "FontString") then
            local text = region:GetText() -- string or nil
			table.insert(ToolTipText, text)
        end
    end
	--Reset first two lines of tooltip
	self:ClearLines()
	self:AddLine(ToolTipText[1])
	self:AddLine(CWhite..ToolTipText[2])
	--fill index list with indicies of matches
	for i = 1, PetListSize do 
		if (PetList[i].SpeciesName == species) then
			counter = counter + 1;
			Owned[counter] = i;
		end
		if (counter == 3) then break end; --Limited 3 of any species
	end
	--Set Captureable text
	if(Owned[3] ~= 0) then --if unable to catch more.
		self:AddLine(CErrorRed.."Not Capturable(Full)")
	else
		self:AddLine(CValidGreen.."Capturable")
	end
	--Get Target's Level
	local targetLevel = (tonumber(string.sub(ToolTipText[2], 10, 12)))
	local arrow
	--add known pet versions to tooltip
	if(Owned[1] ~= 0) then
		self:AddLine("Owned:");
		for i = 1, 3 do	--List owned versions of the species
			local PetID,_,_, nick, lv = C_PetJournal.GetPetInfoByIndex(Owned[i])
			local _,_,_,_, petrarity = C_PetJournal.GetPetStats(PetID)
			name = species;
			if (nick ~= nil) then
				name = nick --add nickname if has one
			end
			if (targetLevel > lv) then
				arrow = "|TInterface\\Minimap\\Minimap-PositionArrows:0:0:0:0:16:32:0:16:16:32|t"
			elseif (targetLevel < lv) then
				arrow = "|TInterface\\Minimap\\Minimap-PositionArrows:0:0:0:0:16:32:0:16:0:16|t"
			else
				arrow = CWhite.."=|r "
			end
			self:AddLine(arrow..name..", Lv"..lv..RarityInfo[petrarity].Color.." ("..RarityInfo[petrarity].Desc..")")
		end
	else
		self:AddLine("None Owned."); --if none owned
	end
end

function TrappersSense.Hijack(self)
	print(true)
end

_G[ADDONNAME] = TrappersSense;
GameTooltip:HookScript("OnTooltipSetUnit", TrappersSense.Hook);
